@@ -1,10 +1,14 @@
-import json
+import simplejson
 
 from django.contrib.auth.models import User
 from django.db import models
 from django.utils.translation import ugettext as _
 
 
+class JSONDataError(ValueError):
+    """Error raised when JSON is syntactically valid but ill-formed."""
+
+
 class DeviceType(models.Model):
     """
     A class of device, for example a pandaboard or a snowball.
@@ -103,10 +107,13 @@ class TestJob(models.Model):
         verbose_name = _(u"Submitter"),
     )
 
-    #description = models.CharField(
-    #    verbose_name = _(u"Description"),
-    #    max_length = 200
-    #)
+    description = models.CharField(
+        verbose_name = _(u"Description"),
+        max_length = 200,
+        null = True,
+        blank = True,
+        default = None
+    )
 
     # Only one of these two should be non-null.
     requested_device = models.ForeignKey(
@@ -164,16 +171,20 @@ class TestJob(models.Model):
 
     @classmethod
     def from_json_and_user(cls, json_data, user):
-        job_data = json.loads(json_data)
+        job_data = simplejson.loads(json_data)
         if 'target' in job_data:
             target = Device.objects.get(hostname=job_data['target'])
             device_type = None
-        else:
+        elif 'device_type' in job_data:
             target = None
             device_type = DeviceType.objects.get(name=job_data['device_type'])
+        else:
+            raise JSONDataError(
+                "Neither 'target' nor 'device_type' found in job data.")
+        job_name = job_data.get('job_name', '')
         job = TestJob(
             definition=json_data, submitter=user, requested_device=target,
-            requested_device_type=device_type)
+            requested_device_type=device_type, description=job_name)
         job.save()
         return job
 
