@@ -58,6 +58,16 @@ class DatabaseJobSource(object):
 
     @transaction.commit_manually()
     def getJobForBoard_impl(self, board_name):
+        # If there is no db connection yet on this thread, create a connection
+        # and immediately commit, because rolling back the first transaction
+        # on a connection loses the effect of settings.TIME_ZONE when using
+        # postgres (see https://code.djangoproject.com/ticket/17062) and this
+        # method has to be able to roll back to avoid assigning the same job
+        # to multiple boards.
+        if connection.connection is None:
+            connection.cursor().close()
+            assert connection.connection is not None
+            transaction.commit()
         while True:
             device = Device.objects.get(hostname=board_name)
             if device.status != Device.IDLE:
@@ -85,6 +95,9 @@ class DatabaseJobSource(object):
                     # same job -- this is an application level bug though.
                     device.save()
                 except IntegrityError:
+                    self.logger.info(
+                        "job %s has been assigned to another board -- "
+                        "rolling back", job.id)
                     transaction.rollback()
                     continue
                 else:
